#[repr(C)]pub struct TarHeader {Show 17 fields
pub name: [u8; 100],
pub mode: [u8; 8],
pub uid: [u8; 8],
pub gid: [u8; 8],
pub size: [u8; 12],
pub mtime: [u8; 12],
pub chksum: [u8; 8],
pub typeflag: u8,
pub linkname: [u8; 100],
pub magic: [u8; 6],
pub version: [u8; 2],
pub uname: [u8; 32],
pub gname: [u8; 32],
pub devmajor: [u8; 8],
pub devminor: [u8; 8],
pub prefix: [u8; 155],
pub padding: [u8; 12],
}Expand description
Represents a tar archive header following the POSIX ustar format.
The header contains metadata about a file in a tar archive, including its name, size, permissions, and other attributes. All text fields are null-terminated.
Fields
name: [u8; 100]mode: [u8; 8]uid: [u8; 8]gid: [u8; 8]size: [u8; 12]mtime: [u8; 12]chksum: [u8; 8]typeflag: u8linkname: [u8; 100]magic: [u8; 6]version: [u8; 2]uname: [u8; 32]gname: [u8; 32]devmajor: [u8; 8]devminor: [u8; 8]prefix: [u8; 155]padding: [u8; 12]Implementations